@@ -18,7 +18,7 @@
 # -----------------------------------------------------------------------------
 # Start/Stop Script for the CATALINA Server
 #
-# Environment Variable Prequisites
+# Environment Variable Prerequisites
 #
 #   CATALINA_HOME   May point at your Catalina "build" directory.
 #
@@ -67,7 +67,7 @@
 #   CATALINA_PID    (Optional) Path of the file which should contains the pid
 #                   of catalina startup java process, when start (fork) is used
 #
-# $Id: catalina.sh 952492 2010-06-07 23:54:51Z kkolinko $
+# $Id: catalina.sh 1040548 2010-11-30 14:48:26Z markt $
 # -----------------------------------------------------------------------------
 
 # OS specific support.  $var _must_ be set to either true or false.
@@ -156,7 +156,7 @@ fi
 CLASSPATH="$CLASSPATH""$CATALINA_HOME"/bin/bootstrap.jar
 
 if [ -z "$CATALINA_BASE" ] ; then
-  CATALINA_BASE="/var/tomcat"
+  CATALINA_BASE="$CATALINA_HOME"
 fi
 
 if [ -z "$CATALINA_OUT" ] ; then
